<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>


<form action="index.php?amn=blg_item" method="post" name="frm" id="id_frm">
<input type="hidden" name="entry_id" value="<?php if(isset($entry['entry_id'])) { echo $entry['entry_id'];}?>" />
<input type="hidden" name="blog_id" value="<?php if(isset($blog['blog_id'])) { echo $blog['blog_id'];}?>" />


<div class="col_main">
	<?php
	if (isset($entry)) {
	?>
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $this->date->formatDate($entry['entry_create_datetime'],1);?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php
				if ($blog['status_id'] != $blog_config['status']['live']) {
				?>
				<div class="picture" style="padding:10px; margin-bottom:20px; width:488px">
					<?php
					if (!empty($blog_config['owner_allow_to_live_status'])) {
					?>
						<?php echo $lang['txt_status_not_live_owner_set'];?><br />

						<p align="right">
							<a href="index.php?amn=blg_item&amp;blog_id=<?php echo $blog['blog_id'];?>&amp;set_status_live=1"><?php echo $lang['href_set_to_live'];?></a><br />
						</p>
					<?php
					}
					else {
					?>
						<?php echo $lang['txt_status_not_live'];?><br />
					<?php }?>
				</div>
				<?php }?>
				
				<?php
				if (isset($_SESSION['user_id'])) {
				?>
				
				<div class="metadata_top">
					<?php
					if (isset($_SESSION['user_id']) && isset($entry['entry_id']) && $_SESSION['user_id'] == $entry['user_id']) {
					?>
					&nbsp;
					&nbsp;
					<a href="index.php?amn=blg_entry_edit&amp;blog_id=<?php echo $blog['blog_id'];?>&amp;entry_id=<?php echo $entry['entry_id'];?>"><?php echo $lang['href_edit_entry'];?></a>
					<?php }?>
					
					
					
					<br />
				</div>
				
				<?php }?>
				
				<p class="txt_item_title">
					<?php echo $entry['entry_title']; ?><br />
				</p>
				
				<div style="overflow: auto; width:510px;margin-top:6px;margin-bottom:6px;">
					<?php echo $entry['entry_body'];?><br />
				</div>
				
				<img src="<?php echo $template_path_core;?>img/pixel.png" width="1" height="12" alt="" /><br />
				
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<tr>
						<td>
							<?php if (isset($matrix[0]['relation']) && !isset($matrix[0]['relation']['respected'])) { ?>
								<a href="index.php?amn=blg_item&amp;respect=1&amp;blog_id=<?php echo $blog['blog_id'];?>&amp;entry_id=<?php echo $entry['entry_id'];?>"><?php echo $lang['href_respect'];?></a>
								&nbsp;
							<?php } ?>
						
						
							<?php echo $this->date->formatDate($entry['entry_create_datetime'],1);?><br />
						</td>
						<td align="right">
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['blog'];?>&amp;identity_id=<?php echo $identity['identity_id'];?>&amp;blog_id=<?php echo $blog['blog_id'];?>"><?php echo $identity['identity_nic'];?></a>

							<?php
							if (isset($matrix)) {
 								echo drawMatrix($matrix[0]);
							} ?>
							
							<?php
							if (isset($identity['testimonial_count'])) {
							?>
							&nbsp; 
							<span class="icon_frame">
								<span class="icon_title">&nbsp;<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['blog'];?>&amp;identity_id=<?php echo $identity['identity_id'];?>&amp;set_id=<?php echo $blog['blog_id'];?>"><?php echo $lang['txt_vouched'];?></a>&nbsp;</span>
								<span class="icon_value">&nbsp;<?php echo $identity['testimonial_count'];?>&nbsp;</span>
							</span>
							<?php }?>
					
							<br />
						</td>
					</tr>
				</table>
				
				
				<?php
				if (isset($_SESSION['user_id']) && $_SESSION['user_id'] != $entry['user_id']) {
				?>
				
				<hr />
				
				<table border="0" cellspacing="0" cellpadding="4">
					<tr>
						<td valign="top">
							<?php echo $lang['txt_relevent'];?><br />
						</td>
						<td nowrap="nowrap">
							<?php
							if (isset($entry['rate']['relevent']['value']) && $entry['rate']['relevent']['value'] == 0) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_down.png" title="<?php echo $lang['txt_title_not_relevent'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_down.png" name="relevent_0" value="0" title="<?php echo $lang['txt_title_set_not_relevent'];?>" alt="<?php echo $lang['txt_alt_not_relevent'];?>" border="0" />
							<?php }?>
							
							<?php
							if (isset($entry['rate']['relevent']['value']) && $entry['rate']['relevent']['value'] == 1) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_up.png" title="<?php echo $lang['txt_title_relevent'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_up.png" name="relevent_1" value="1" title="<?php echo $lang['txt_title_set_relevent'];?>" alt="<?php echo $lang['txt_alt_relevent'];?>" border="0" />
							<?php }?>
							
							
						</td>
						<td valign="top">
							<?php
							if (isset($entry['rate']['relevent']['value'])) {
							?>
							<?php echo $lang['txt_relevent_summary'];?><br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_accurate'];?><br />
						</td>
						<td nowrap="nowrap">
							<?php
							if (isset($entry['rate']['accurate']['value']) && $entry['rate']['accurate']['value'] == 0) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_down.png" title="<?php echo $lang['txt_title_not_accurate'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_down.png" name="accurate_0" value="0" title="<?php echo $lang['txt_title_set_not_accurate'];?>" alt="<?php echo $lang['txt_alt_not_accurate'];?>" border="0" />
							<?php }?>
							
							<?php
							if (isset($entry['rate']['accurate']['value']) && $entry['rate']['accurate']['value'] == 1) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_up.png" title="<?php echo $lang['txt_title_accurate'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_up.png" name="accurate_1" value="1" title="<?php echo $lang['txt_title_set_accurate'];?>" alt="<?php echo $lang['txt_alt_accurate'];?>" border="0" />
							<?php }?>
						</td>
						<td valign="top">
							<?php
							if (isset($entry['rate']['accurate']['value'])) {
							?>
							<?php echo $lang['txt_accurate_summary'];?><br />
							<?php }?>
						</td>
					</tr>
				</table>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_comments'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				$profile_url = "index.php?amn=core_profile&amp;module_id=" . $core_config['module_id']['blog'] . "&amp;item_id=" . $blog['blog_id'];
				?>
				
				<?php
				include $template_path_core . "inc/comment.inc.php";
				?>
				<hr />
				
				<?php
				if (isset($participation)) {
					include $template_path_core . "inc/add_comment.inc.php";
				}
				else {
					echo $lang['txt_participate_first'];
				}
				?>
				
				</form>
			</div>
		</div>
	</div>
	<?php
	}
	else { // blog with no entries
	?>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_blog'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if ($blog['status_id'] != $blog_config['status']['live']) {
				?>
				<div class="picture" style="padding:10px; margin-bottom:20px; width:488px">
					<?php
					if (!empty($blog_config['owner_allow_to_live_status'])) {
					?>
						<?php echo $lang['txt_status_not_live_owner_set'];?><br />

						<p align="right">
							<a href="index.php?amn=blg_item&amp;blog_id=<?php echo $blog['blog_id'];?>&amp;set_status_live=1"><?php echo $lang['href_set_to_live'];?></a><br />
						</p>
					<?php
					}
					else {
					?>
						<?php echo $lang['txt_status_not_live'];?><br />
					<?php }?>
				</div>
				<?php }?>
				
				<p>
					<?php echo $lang['txt_no_entries'];?><br />
				</p>
			</div>
		</div>
	</div>
	<?php }?>
</div>

<div class="col_side">
	<?php
	if (isset($_SESSION['user_id'])) {
	?>
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_my_participation'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (!empty($participation)) {
				?>
				<table cellspacing="2" cellpadding="2" border="0">
					<tr>
						<td valign="top">
							<?php echo $lang['txt_joined'];?><br />
						</td>
						<td valign="top">
							<?php echo $this->date->formatDate($participation['participation_create_datetime']);?><br />
						</td>
					</tr>
					<?php
					if (isset($participation['role_id'])) {
					?>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_role'];?><br />
						</td>
						<td valign="top">
							<?php echo $lang['user_role'][$participation['role_id']];?><br />
						</td>
					</tr>
					<?php }?>
					
					<?php
					if (isset($participation['status_id'])) {
					?>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_status'];?><br />
						</td>
						<td valign="top">
							<?php echo $lang['user_participation_status'][$participation['status_id']];?><br />
						</td>
					</tr>
					<?php }?>
				</table>
				<?php
				}
				else {
				?>
				<p>
					<?php echo $lang['blog_type'][$blog['blog_type']];?>
				
					<?php
					if (($blog['blog_type'] == $blog_config['type']['membership_type']) || ($blog['blog_type'] == $blog_config['type']['approved']) || ($blog['blog_type'] == $blog_config['type']['open'])) {
					?>
					: <a href="index.php?amn=core_participation&amp;module_id=<?php echo $core_config['module_id']['blog'];?>&amp;item_id=<?php echo $blog['blog_id'];?>" class="href_button"><?php echo $lang['href_join'];?></a><br />
					<?php }?>
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	<?php }?>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=blg_index');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>
				
				<h1><?php echo $lang['hdr_blog'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p align="right">
					<?php
					if (isset($_SESSION['user_id'])) {
					?>
						<a href="feed.php?mid=<?php echo $core_config['module_id']['blog'];?>&amp;iid=<?php echo $blog['blog_id'];?>"><input type="image" src="<?php echo $template_path_core;?>img/rss.png" name="rss" value="0" alt="<?php echo $lang['txt_alt_rss'];?>" border="0" title="<?php echo $lang['txt_title_rss'];?>" /></a>
						
						&nbsp;
						
						<?php
						if (isset($blog['bookmark']['watch'])) {
						?>
							<input type="image" src="<?php echo $template_path_core;?>img/unmark.png" name="mark_0" value="0" alt="<?php echo $lang['txt_alt_remove_bookmark'];?>" border="0" title="<?php echo $lang['txt_title_remove_bookmark'];?>" />
						<?php
						}
						else {
						?>
							<input type="image" src="<?php echo $template_path_core;?>img/mark.png" name="mark_1" value="1" alt="<?php echo $lang['txt_alt_add_bookmark'];?>" border="0" title="<?php echo $lang['txt_title_add_bookmark'];?>" />
							&nbsp;
							<input type="image" src="<?php echo $template_path_core;?>img/track.png" name="mark_2" value="2" alt="<?php echo $lang['txt_alt_add_track'];?>" title="<?php echo $lang['txt_title_add_track'];?>" border="0" />
						<?php }?>
						
						&nbsp;
						
						<?php
						if (isset($blog['bookmark']['recommend'])) {
						?>
							<input type="image" src="<?php echo $template_path_core;?>img/unrecommend.png" name="recommend_0" value="0" alt="<?php echo $lang['txt_alt_remove_recommendation'];?>" border="0" title="<?php echo $lang['txt_title_remove_recommendation'];?>" />
						<?php
						}
						else {
						?>
							<input type="image" src="<?php echo $template_path_core;?>img/recommend.png" name="recommend_1" value="1" alt="<?php echo $lang['txt_alt_add_recommendation'];?>" border="0" title="<?php echo $lang['txt_title_add_recommendation'];?>" />
						<?php }?>
					&nbsp;
					<?php }?>
				</p>
				
				<p>
					<b><?php echo $blog['blog_title'];?><br /></b><br />
					<?php echo $blog['blog_synopsis'];?><br />
				</p>
				
				<p align="right">
					<?php
					if (isset($participation) && $participation['participation_permission'] & $blog_config['resource']['user']['allow_create_entry']) {
					?>
					<a href="index.php?amn=blg_entry_edit&amp;blog_id=<?php echo $blog['blog_id'];?>"><?php echo $lang['href_create_entry'];?></a>
					<?php }?>

					<?php
					if (isset($_SESSION['user_id']) && $_SESSION['user_id'] == $blog['user_id']) {
					?>
					&nbsp;
					<a href="index.php?amn=blg_blog_edit&amp;blog_id=<?php echo $blog['blog_id'];?>"><?php echo $lang['href_edit_blog'];?></a>
					<?php }?>
					<br />
				</p>
				
				<?php
				if (isset($authors)) {
				?>
				
				<p>
					<b><?php echo $lang['txt_authors'];?></b><br />
					<?php
					foreach ($authors as $key => $i):
					?>
					<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['blog'];?>&amp;identity_id=<?php echo $i['identity_id'];?>&amp;blog_id=<?php echo $blog['blog_id'];?>"><?php echo $i['identity']['identity_nic'];?></a><br />
					<?php
					endforeach;
					?>
				</p>
				<?php }?>
				
				<?php
				if (isset($blogroll)) {
				?>
				<p>
					<b><?php echo $lang['txt_blogroll'];?></b><br />
				</p>
				
				<p>
					<?php
					foreach($blogroll as $key => $i):
					?>
					<a href="index.php?amn=blg_item&amp;blog_id=<?php echo $i['related_blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
					<?php
					endforeach;
					?>
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	
	<?php
	if (isset($entries)) {
	?>
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_entries'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php
					foreach ($entries as $key => $i):
					if (isset($entry['entry_id']) && $i['entry_id'] == $entry['entry_id']) {
					?>
					<?php echo $this->date->formatDate($i['entry_create_datetime'],1);?>
					<?php
					}
					else {
					?>
					<a href="index.php?amn=blg_item&amp;blog_id=<?php echo $blog['blog_id'];?>&amp;entry_id=<?php echo $i['entry_id'];?>"><?php echo $this->date->formatDate($i['entry_create_datetime'],1);?></a>
					<?php }?>
					
					<?php 
					if (isset($entry['entry_id']) && $i['entry_id'] == $entry['entry_id']) {				
						echo "*";
					}
					?>
					<br />
					<?php
					endforeach;
					?>
				</p>
				
				<p align="right">
					<a href="index.php?amn=blg_list&amp;blog_id=<?php echo $blog['blog_id'];?>"><?php echo $lang['href_list'];?></a><br />
				</p>
			</div>
		</div>
	</div>
	<?php }?>
	
	
	<?php
	if (isset($_SESSION['user_id']) && isset($entry)) {
	?>
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_tags');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>

				<h1><?php echo $lang['hdr_tags'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_tags'];?></b><br />
					<?php
					if (isset($tags)) {
					$prnt = "";
					foreach($tags as $key => $i):
						$prnt .= $i['tag_body'] . "<sup><a href='index.php?amn=blg_item&amp;entry_id=" . $entry['entry_id'] . "&amp;edit_tag=" . $i['tag_id'] . "' style='text-decoration:none;'>&#43;</a></sup> ";
					endforeach;
					echo $prnt;
					}
					?>
				</p>
				
				<p>
					<input type="hidden" name="tag_id" value="<?php if (isset($tag)) { echo $tag['tag_id'];}?>" />
					<input type="text" class="input1" name="tag_body" size="10" value="<?php if (isset($tag)) { echo $tag['tag_body'];}?>" /><br />
				</p>
				
				<p style="float:right; margin-bottom:0px; margin-top:0px;">
					<input type="submit" name="insert_tag" class="input_submit" style="font-size:60%;" value="<?php echo $lang['sub_tag_ok'];?>" />
					<input type="submit" name="delete_tag" class="input_submit" style="font-size:60%;" value="<?php echo $lang['sub_tag_delete'];?>" /><br />
				</p>
			</div>
		</div>
	</div>
	<?php }?>
</div>
</form>